==> kconfig-5.29.0.tar.xz: kconfig-5.29.0/autotests/kconfig_compiler/test1main.cpp <==
/*
Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#include "test1.h"
#include <QGuiApplication>
#include <KConfig>
#include <KConfigGroup>

int main(int argc, char **argv)
{
    QGuiApplication app(argc, argv);
    Q_UNUSED(app);

    {
        KConfig initialConfig(QLatin1String("examplerc"));
        KConfigGroup group = initialConfig.group(QLatin1String("MyOptions"));
        group.writeEntry(QLatin1String("MyString"), QStringLiteral("The String"));
    }
    Test1 *t = new Test1(QString(), QString());

    bool ok = t->myString() == QLatin1String("The String");

    delete t;
    return ok ? 0 : 1;
}

==> kconfig-5.58.0.tar.xz: kconfig-5.58.0/autotests/kconfig_compiler/test1main.cpp <==
/*
Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#include "test1.h"
#include <QGuiApplication>
#include <KConfig>
#include <KConfigGroup>

int main(int argc, char **argv)
{
    QGuiApplication app(argc, argv);
    Q_UNUSED(app);

    {
        KConfig initialConfig(QStringLiteral("examplerc"));
        KConfigGroup group = initialConfig.group(QStringLiteral("MyOptions"));
        group.writeEntry(QStringLiteral("MyString"), QStringLiteral("The String"));
    }
    Test1 *t = new Test1(QString(), QString());

    bool ok = t->myString() == QLatin1String("The String");

    delete t;
    return ok ? 0 : 1;
}
